@@ -27,8 +27,7 @@ THE SOFTWARE. */
  * Created on March 5, 2009, 9:26 PM
  */
 
-#ifndef M_AboutDialog_hpp
-#define	M_AboutDialog_hpp
+#pragma once
 
 #include <gtkmm/dialog.h>
 #include <gtkmm/label.h>
@@ -39,4 +38,3 @@ public:
 	AboutDialog(Gtk::Window &parent);
 };
 
-#endif//~once
