@@ -28,7 +28,8 @@ using namespace ting;
 MainThread::MainThread() :
 		networkThread(this),
 		networkState(OFFLINE),
-		reconnectTime(MainThread::DMinReconnectTime())
+		reconnectTime(MainThread::DMinReconnectTime()),
+		isListening(false)
 {
 	this->musicActionsBuffer.reserve(8196);//8kb
 }
@@ -194,7 +195,7 @@ void NetworkDataFromServerMessage::Handle(){
 			this->mt->HandleStopListeningMessageFromServer(this->data);
 			break;
 		case 0x03:
-			this->mt->playbackThread.PushNewPlaybackData_ts(this->data);
+			this->mt->HandleListeningMusicDataFromServer(this->data);
 			break;
 		default:
 			ASSERT_INFO(false, "unknown message id = " << ((u32)this->data[0]))
@@ -371,14 +372,21 @@ u32 MainThread::SendMusicActionsTimer::OnExpire(){
 
 
 
-void MainThread::SendListenNextCommandToServer_ts(){
+void MainThread::ListenNext_ts(){
+	this->isListening = true;
 	this->networkThread.SendListenNextToServer_ts();
 }
 
 
 
-void MainThread::SendStopListeningCommandToServer_ts(){
+void MainThread::StopListening_ts(){
+	this->isListening = false;
+
+	//tell server to remove listener from cast
 	this->networkThread.SendStopListeningToServer_ts();
+
+	//reset playback to prevent any notes remaining on
+	this->playbackThread.ResetPlayback_ts();
 }
 
 
@@ -518,6 +526,17 @@ void MainThread::HandleLoginResultFromServer(ting::Array<ting::byte> p){
 
 
 
+void MainThread::HandleListeningMusicDataFromServer(ting::Array<ting::byte> p){
+	if(!this->isListening){
+		//not in listening state, ignore packet
+		return;
+	}
+
+	this->playbackThread.PushNewPlaybackData_ts(p);
+}
+
+
+
 void MainThread::HandlePlayerSwitchMessageFromServer(ting::Array<ting::byte> p){
 	ting::uint i = 0;
 
@@ -567,6 +586,9 @@ void MainThread::HandleStopListeningMessageFromServer(ting::Array<ting::byte> p)
 		return;
 	}
 
+	//reset playback to prevent any notes remaining on
+	this->playbackThread.ResetPlayback_ts();
+
 	this->currentPlayerListeners.SetCurrentPlayer(std::string());//empty string
 	this->currentPlayerListeners.Notify_ts();
 }
