@@ -197,6 +197,9 @@ private:
 private:
 	PlaybackThread playbackThread;
 
+	//indicates listening state
+	bool isListening;
+
 	ting::uint numActionsInBuffer;
 	std::vector<ting::byte> musicActionsBuffer;
 
@@ -215,15 +218,16 @@ public:
 	//override
 	void Run();
 
-	void SendListenNextCommandToServer_ts();//_ts stands for 'threadsafe'
-
-	void SendStopListeningCommandToServer_ts();
+	void ListenNext_ts();//_ts stands for 'threadsafe'
 
+	void StopListening_ts();
 
 private:
 
 	void HandleLoginResultFromServer(ting::Array<ting::byte> p);
 
+	void HandleListeningMusicDataFromServer(ting::Array<ting::byte> p);
+
 	void HandlePlayerSwitchMessageFromServer(ting::Array<ting::byte> p);
 
 	void HandleStopListeningMessageFromServer(ting::Array<ting::byte> p);
