@@ -49,17 +49,19 @@ Lib::Lib(ting::uint requestedBufferSizeInFrames) :
 
 
 Lib::~Lib(){
+//	TRACE(<< "aumiks::~Lib(): enter")
 	//need to stop thread before closing the device
 	//because it can attempt write data after the device is closed
 	this->thread.Join();
-};
+//	TRACE(<< "aumiks::~Lib(): exit")
+}
 
 
 
 void Lib::PlayChannel(ting::Ref<Channel> ch){
 	ASSERT(ch.IsValid())
 	
-	ting::Mutex::LockerUnlocker mut(this->thread.chPoolMutex);
+	ting::Mutex::Guard mut(this->thread.chPoolMutex);
 	if(ch->IsPlaying())
 		return;//already playing
 	this->thread.chPoolToAdd.push_back(ch);//queue channel to be added to playing pool
@@ -99,21 +101,22 @@ static void CopyFromMixBufToPlayBuf(const Array<s32>& mixBuf, Array<ting::byte>&
 
 
 void Lib::SoundThread::Run(){
+	M_AUMIKS_TRACE(<< "Thread started" << std::endl)
 	ting::Ptr<aumiks::AudioBackend> backend(new ALSABackend(this->desiredBufferSizeInFrames));
 //	ting::Ptr<aumiks::AudioBackend> backend(new ESoundBackend(this->desiredBufferSizeInFrames));
 
 	ting::Array<s32> mixBuf(backend->BufferSizeInSamples());
 	ting::Array<ting::byte> playBuf(backend->BufferSizeInBytes());
 
-	TRACE(<< "mixBuf.Size() = " << mixBuf.Size() << std::endl)
+	M_AUMIKS_TRACE(<< "mixBuf.Size() = " << mixBuf.Size() << std::endl)
 
 	while(!this->quitFlag){
 		//clean mixBuf
 		memset(mixBuf.Buf(), 0, mixBuf.SizeInBytes());
 
 		{//add queued channels to playing pool
-			ting::Mutex::LockerUnlocker mut(this->chPoolMutex);//lock mutex
-//			TRACE(<< "chPoolToAdd.size() = " << this->chPoolToAdd.size() << std::endl)
+			ting::Mutex::Guard mut(this->chPoolMutex);//lock mutex
+			M_AUMIKS_TRACE(<< "chPoolToAdd.size() = " << this->chPoolToAdd.size() << std::endl)
 			while(this->chPoolToAdd.size() != 0){
 				ting::Ref<aumiks::Channel> ch = this->chPoolToAdd.front();
 				this->chPoolToAdd.pop_front();
@@ -132,11 +135,11 @@ void Lib::SoundThread::Run(){
 		}
 
 //		TRACE(<< "chPool.size() = " << this->chPool.size() << std::endl)
-//		TRACE(<< "mixed, mixbuf[0] = "<< this->mixBuf[0] << std::endl)
+		M_AUMIKS_TRACE(<< "mixed, copying to playbuf..." << std::endl)
 
 		CopyFromMixBufToPlayBuf(mixBuf, playBuf);
 
-//		TRACE(<< "SoundThread::Run(): writing data" << std::endl)
+		M_AUMIKS_TRACE(<< "SoundThread::Run(): writing data..." << std::endl)
 
 		//write data
 		backend->Write(playBuf);
