@@ -51,7 +51,7 @@ public:
 	public:
 		inline Channel() :
 				lastVolume(-1)
-		{};
+		{}
 
 		virtual void SetFrequency(float freq){}
 	};
@@ -108,6 +108,7 @@ public:
 };
 
 
+
 class SineWaveInstrument : public Instrument{
 public:
 
@@ -143,7 +144,7 @@ public:
 				envPhase(ATTACK)
 		{
 			this->SetFrequency(440);
-		};
+		}
 
 		//override
 		// freq in Hz
@@ -153,13 +154,14 @@ public:
 			this->decayTime = 1000.0f * 20.0f / freq;
 			this->sustainLevel = 0.4f;
 			this->releaseTime = 1000.0f * 30.0f / freq;
-		};
+		}
 
 	private:
 		//override
 		bool MixToMixBuf(Array<s32>& mixBuf);
 	};
 
+	//override
 	Ref<Instrument::Channel> CreateChannel();
 
 	static inline ting::Ref<SineWaveInstrument> New(){
@@ -167,5 +169,69 @@ public:
 	}
 };
 
+
+
+class SampledInstrument : public Instrument{
+public:
+
+#ifdef M_USE_FIXED_POINT
+	typedef Fixed<13> real;
+#else
+	typedef float real;
+#endif
+
+	class Channel : public Instrument::Channel{
+		real curPhase;
+//
+		real curTime; //in milliseconds
+		enum EEnvelopePhase{
+			ATTACK,
+			DECAY,
+			SUSTAIN,
+			RELEASE
+		} envPhase;
+//
+//		real phaseStep;// (Hz / 44100) * 2pi
+//		real attackTime;//ms
+//		real decayTime;//ms
+//		real sustainLevel;
+//		real releaseTime;//ms
+//
+//		real releaseFromLevel;
+	public:
+
+		Channel() :
+				curPhase(0),
+				curTime(0),
+				envPhase(ATTACK)
+		{
+			this->SetFrequency(440);
+		}
+
+		//override
+		// freq in Hz
+		void SetFrequency(float freq){
+//			this->phaseStep = D2Pi<real>() * real(freq) / real(44100);
+//			this->attackTime = 1000.0f * 20.0f / freq;
+//			this->decayTime = 1000.0f * 20.0f / freq;
+//			this->sustainLevel = 0.4f;
+//			this->releaseTime = 1000.0f * 30.0f / freq;
+		};
+
+	private:
+		//override
+		bool MixToMixBuf(Array<s32>& mixBuf);
+	};
+
+	//override
+	Ref<Instrument::Channel> CreateChannel();
+
+//	static inline ting::Ref<SampledInstrument> New(){
+//		return ting::Ref<SampledInstrument>(new SampledInstrument());
+//	}
+};
+
+
+
 }//~namespace
 #endif	//~once
